@@ -20,8 +20,10 @@ int get_codec_name_list(codec_name_t* names, int entries)
         const gchar* dirname = g_dir_read_name(sysdir);
         if (!dirname)
             break;
+        /* Split e g "hwC0D1" into "hw", "0" and "1" */
         cd = g_strsplit_set(dirname, "CD", 9);
         ok = g_strv_length(cd) == 3;
+        ok &= strcmp(cd[0], "hw") == 0;
         if (ok) {
             gchar* filetest = g_strdup_printf("/sys/class/sound/%s/init_pin_configs", dirname);
             ok = g_file_test(filetest, G_FILE_TEST_IS_REGULAR);
