@@ -19,6 +19,7 @@
  *
  */
  
+#include <stdlib.h>
 #include "strglobal.h"
 #include "strparam.h"
 #include "structure.h"
@@ -129,6 +130,8 @@ int StrGlobal::loadFromLD(void)
 				fx->setName(ioname);
 				fx->setFlagChanged(true);
 			}
+			// Don't make unconnected IO/FX disappear.
+			fx->setFlagUsed(true);
 		}
 		else
 		{
@@ -154,6 +157,7 @@ int StrGlobal::loadFromLD(void)
 				in->setName(ioname);
 				in->setFlagChanged(true);
 			}
+			in->setFlagUsed(true);
 		}
 		else
 		{
@@ -179,6 +183,7 @@ int StrGlobal::loadFromLD(void)
 				out->setName(ioname);
 				out->setFlagChanged(true);
 			}
+			out->setFlagUsed(true);
 		}
 		else
 		{
